@@ -1,7 +1,7 @@
 #! /usr/bin/perl
 
 # ex:ts=8 sw=4:
-# $OpenBSD: Quirks.pm,v 1.362 2016/02/04 12:34:48 sthen Exp $
+# $OpenBSD: Quirks.pm,v 1.407 2016/07/11 10:16:48 sthen Exp $
 #
 # Copyright (c) 2009 Marc Espie <espie@openbsd.org>
 #
@@ -73,7 +73,6 @@ my $base_exceptions = {
 	'p5-ExtUtils-CBuilder' => "$p5/ExtUtils/CBuilder.pm",
 	'p5-ExtUtils-ParseXS' => "$p5/ExtUtils/ParseXS.pm",
 	'p5-Locale-Maketext-Simple' => "$p5/Locale/Maketext/Simple.pm",
-	'p5-Module-Build' =>  "$p5/Module/Build.pm",
 	'p5-Module-CoreList' => "$p5/Module/CoreList.pm",
 	'p5-Module-Load' => "$p5/Module/Load.pm",
 	'p5-Module-Loaded' => "$p5/Module/Loaded.pm",
@@ -100,6 +99,8 @@ my $base_exceptions = {
 # 5.8
 	'libepoxy' => '/usr/X11R6/lib/libepoxy.so.1.0',
 	'flex' => '/usr/bin/flex',
+# 6.0
+	'p5-Term-ReadKey' => "$p5a/Term/ReadKey.pm",
 };
 
 my $stem_extensions = {
@@ -395,9 +396,16 @@ my $stem_extensions = {
 	'apertium-nn-nb' => 'apertium-nno-nob',
 	'weblint' => 'p5-HTML-Lint',
 	'py-fabric' => 'fabric',
+# 6.0
+	'cosmic-sans-neue-mono' => 'fantasque-sans',
+	'droid-fonts' => 'noto-fonts',
+	'py-logilab-astng' => 'py-astroid',
+	'apache-httpd-openbsd' => 'apache-httpd',
+	'openmotif' => 'motif',
+	'go-websocket' => 'go-net',
+	'letsencrypt' => 'certbot',
 };
 
-# reasons for obsolete packages
 my $obsolete_reason = {
 	'BitTorrent' => 0,
 	'BitTorrent-gui' => 0,
@@ -731,8 +739,96 @@ my $obsolete_reason = {
 	'hs-simple-sendfile' => 5,
 	'monadius' => 3,
 	'hs-bimap' => 5,
+	'nicotine' => 3,
+	'toprump' => 3,
+	'fedora_base' => 0,
+	'fedora_cups' => 0,
+	'fedora_gtk+2' => 0,
+	'adom' => 0,
+	'xcept' => 0,
+	'cqcam' => 6,
+	'uisp' => 6,
+        'libretto-config' => 6,
+	'courtney' => 2,
+	'junkbuster' => 2,
+	'icb' => 0,
+	'libshrink' => 3,
+	'libclog' => 3,
+	'libexude' => 3,
+	'assl' => 3,
+	'libxmlsd' => 3,
+	'p5-Text-Restructured' => 3,
+	'p5-Safe-World' => 3,
+	'p5-Safe-Hole' => 3,
+	'p5-Slay-Makefile-Gress' => 3,
+	'p5-Slay-Makefile' => 3,
+	'p5-Slay-Maker' => 3,
+	'mpegaudio' => 0,
+	'fvwm95' => 0,
+	'rplay' => 0,
+	'amsn' => 6,
+	'pebrot' => 6,
+	'alacarte' => 3,
+	'logstash-forwarder' => 3,
+	'py-Xlib' => 5,
+	'pypanel' => 3,
+	'gtkhtml3' => 5,
+	'libunique3' => 5,
+	'swfdec' => 3,
+	'asm' => 5,
+	'libqzeitgeist' => 6,
+	'zeitgeist' => 6,
+	'gedit-latex' => 3,
+	'rackmonkey' => 3,
+	'mod_auth_bsd' => 6,
+	'mod_auth_ldap' => 6,
+	'mod_auth_mysql' => 6,
+	'mod_auth_pgsql' => 6,
+	'mod_auth_radius' => 6,
+	'mod_encoding' => 6,
+	'mod_fastcgi' => 6,
+	'mod_geoip' => 6,
+	'mod_gzip' => 6,
+	'mod_jk' => 6,
+	'mod_layout' => 6,
+	'mod_ldapvhost' => 6,
+	'mod_log_sql' => 6,
+	'mod_mp3' => 6,
+	'mod_random' => 6,
+	'mod_scgi' => 6,
+	'mod_security' => 6,
+	'mod_text2html' => 6,
+	'p5-CGI-SpeedyCGI' => 6,
+	'p5-HTML-Embperl' => 6,
+	'p5-libapreq' => 6,
+	'mod_perl' => 6,
+	'ocamlduce' => 0,
+	'yt' => 0,
+	'gmime-sharp' => 6,
+	'py-subvertpy' => 5,
+
+# KDE3 removals
+	'amarok' => 2,
+	'digikam-doc' => 6,
+	'gwenview-i18n' => 6,
+	'kaffeine' => 6,
+	'kbiff' => 6,
+	'kdbg' => 3,
+	'kdewebdev' => 5,
+	'kmplayer' => 6,
+	'kountdown' => 3,
+	'krusader' => 2,
+	'kslide' => 3,
+	'ktimeclock' => 6,
+	'okle' => 2,
+	'qinx' => 6,
+	'quadkonsole' => 6,
+	'taskjuggler' => 6,
+	'icinga2-migration' => 3,
+	'poppassd' => 0,
 };
 
+# reasons for obsolete packages
 my @msg = (
 	"ancient software that doesn't work", #0
 	"web application with no benefit being packaged", #1
@@ -823,22 +919,23 @@ sub tweak_search
 # list of
 #   cat/path => badspec
 my $cve = {
-	'print/cups,-main' => 'cups-<1.7.4',
-	'sysutils/mcollective' => 'mcollective-<2.5.3',
-	'net/transmission,-main' => 'transmission-<2.84',
-	'net/transmission,-gtk' => 'transmission-gtk-<2.84',
-	'net/transmission,-qt' => 'transmission-qt-<2.84',
-	'www/bozohttpd' => 'bozohttpd-<20130711p0',
-	'mail/exim' => 'exim-<4.83',
-	'www/p5-CGI-Application' => 'p5-CGI-Application-<4.50p0',
-	'www/cherokee,-ldap' => 'cherokee-ldap-<1.2.101p6',
-	'shells/bash' => 'bash-<4.3.27',
-	'www/drupal7/core' => 'drupal->=7.0,<7.32',
 	'audio/flac' => 'flac-<1.3.0p1',
-	'www/drupal6/views' => 'drupal6-views-<2.18',
-	'graphics/tiff' => 'tiff-<4.0.4beta',
-	'net/lldpd' => 'lldpd-<0.7.18p0',
 	'devel/pcre' => 'pcre-<8.38',
+	'graphics/tiff' => 'tiff-<4.0.4beta',
+	'mail/exim' => 'exim-<4.83',
+	'net/lldpd' => 'lldpd-<0.7.18p0',
+	'net/ntp' => 'ntp-<4.2.8pl7',
+	'net/transmission,-gtk' => 'transmission-gtk-<2.84',
+	'net/transmission,-main' => 'transmission-<2.84',
+	'net/transmission,-qt' => 'transmission-qt-<2.84',
+	'print/cups,-main' => 'cups-<1.7.4',
+	'shells/bash' => 'bash-<4.3.27',
+	'sysutils/mcollective' => 'mcollective-<2.5.3',
+	'www/bozohttpd' => 'bozohttpd-<20130711p0',
+	'www/cherokee,-ldap' => 'cherokee-ldap-<1.2.101p6',
+	'www/drupal6/views' => 'drupal6-views-<2.18',
+	'www/drupal7/core' => 'drupal->=7.0,<7.32',
+	'www/p5-CGI-Application' => 'p5-CGI-Application-<4.50p0',
 };
 
 # ->check_security($path)
